===================================================
``z3c.rml`` -- An alternative implementation of RML
===================================================

This is an alternative implementation of ReportLab's RML PDF generation XML
format. Like the original implementation, it is based on ReportLab's
``reportlab`` library.

You can read all about ``z3c.rml`` and see many examples on how to use it,
see the `RML Reference`_

.. _RML Reference: https://github.com/zopefoundation/z3c.rml/blob/master/src/z3c/rml/rml-reference.pdf?raw=true

Travis: |buildstatus|_

.. |buildstatus| image:: https://api.travis-ci.org/zopefoundation/z3c.rml.png?branch=master
.. _buildstatus: https://travis-ci.org/zopefoundation/z3c.rml
